
%PredatorPrey.m - is the main function for solving, and viewing the 
%numerical solutions to the well known Lotka-Volterra equations.                            
%         
%Detailed explanation - Initial conditions are specified by the user (i.e.,
%                       the number of prey and predators, and the time 
%                       interval with which to view their behaviour). 
%                       Additionally, step size and number of intervals is
%                       defined.
%
%                       Finally, the RK4 routine is used to obtain the
%                       numerical solutions to the Lotka-Volterra system of
%                       differential equations, and are plotting against
%                       time, and against eachother (phase plot).
%                                             
%%

%Desired time interval with which to analyze the predator-prey relation
t0 = input('Enter the starting value of t: ');
tf = input('Enter the end value of t: ');

%Initial numbers of prey and predator respectively
x0 = input('Enter initial number of prey: ');
y0 = input('Enter initial number of predators: ');

%Step size: for this specific task, h = 0.01 yields the greatest resolution
h = 0.01;

%Number of intervals
n = (tf-t0)/h; 

%Runge-Kutta (RK4) routine
[R] = RK4(x0,y0,t0,h,n); 

%Plotting solution functions x(t) and y(t) against time
figure(1)
plot(R(1:n+1, 1), [R(1:n+1, 2), R(1:n+1, 3)], '--');
legend('Prey - x(t)','Predators - y(t)', 'location', 'northwest');
title('Predator-prey model');
xlabel('Time'); ylabel('Prey - x(t), Predators - y(t)');

%Plotting phase space plot of the predator-prey model
figure(2)
plot(R(1:n+1, 2), R(1:n+1, 3));
title('Predator-prey phase space plot');
xlabel('Predator function'); ylabel('Prey function');
saveas(2, 'phase2.eps', 'epsc2');


